##  Including Custom Fact Sheet Fields in Views
Custom fields don't automatically appear in diagram views. To show a custom field in diagram views:
  1. Open a fact sheet and go to More actions > Configuration.
  2. Select a field.
  3. To include the field in diagram views, go to the Options tab (gear icon) and toggle Include in views.
![The Options tab showing the toggled Include in views setting.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio78fa69ae41ab49c08b8c47e1c6f39d4f_LowRes.png)
  4. Choose Review Changes > Apply.


This option is only available for certain field types. For details, see [Showing Fields in Views](https://help.sap.com/docs/leanix/ea/fact-sheet-fields?locale=en-US&state=PRODUCTION&version=CLOUD#loio2759fb817a44101492ded5b080b9f10c__showing_fields_in_views).
